

module("luci.statistics.rrdtool.definitions.netlink", package.seeall)

function rrdargs( graph, plugin, plugin_instance )
	local traffic = {
		title = "%H: Netlink - Transfer on %pi",
		vlabel = "Bytes/s",
		data = {
			sources = {
				if_octets = { "tx", "rx" }
			},
			options = {
				if_octets__tx = {
					total = true,		-- report total amount of bytes
					color = "00ff00"	-- tx is green
				},

				if_octets__rx = {
					flip  = true,		-- flip rx line
					total = true,		-- report total amount of bytes
					color = "0000ff"	-- rx is blue
				}
			}
		}
	}
	local packets = {
		title = "%H: Netlink - Packets on %pi",
		vlabel = "Packets/s", detail = true,
		data = {
			types = { "if_packets", "if_dropped", "if_errors" },
			sources = {
				if_packets = { "tx", "rx" },
				if_dropped = { "tx", "rx" },
				if_errors  = { "tx", "rx" }
			},
			options = {
				if_packets__tx = {
					overlay = true,		-- don't summarize
					total   = true,		-- report total amount of bytes
					color   = "00ff00"	-- processed tx is green
				},
				if_packets__rx = {
					overlay = true,		-- don't summarize
					flip    = true,		-- flip rx line
					total   = true,		-- report total amount of bytes
					color   = "0000ff"	-- processed rx is blue
				},
				if_dropped__tx = {
					overlay = true,		-- don't summarize
					total   = true,		-- report total amount of bytes
					color   = "660055"	-- dropped tx is ... dunno ;)
				},
				if_dropped__rx = {
					overlay = true,		-- don't summarize
					flip    = true,		-- flip rx line
					total   = true,		-- report total amount of bytes
					color   = "440066"	-- dropped rx is violett
				},
				if_errors__tx = {
					overlay = true,		-- don't summarize
					total   = true,		-- report total amount of packets
					color   = "ff5500"	-- tx errors are orange
				},
				if_errors__rx = {
					overlay = true,		-- don't summarize
					flip    = true,		-- flip rx line
					total   = true,		-- report total amount of packets
					color   = "ff0000"	-- rx errors are red
				}
			}
		}
	}
	local multicast = {
		title = "%H: Netlink - Multicast on %pi",
		vlabel = "Packets/s", detail = true,
		data = {
			types = { "if_multicast" },
			options = {
				if_multicast = {
					total = true,		-- report total amount of packets
					color = "0000ff"	-- multicast is blue
				}
			}
		}
	}
	local collisions = {
		title = "%H: Netlink - Collisions on %pi",
		vlabel = "Collisions/s", detail = true,
		data = {
			types = { "if_collisions" },
			options = {
				if_collisions = {
					total = true,		-- report total amount of packets
					color = "ff0000"	-- collsions are red
				}
			}
		}
	}
	local errors = {
		title = "%H: Netlink - Errors on %pi",
		vlabel = "Errors/s", detail = true,
		data = {
			types = { "if_tx_errors", "if_rx_errors" },
			instances = {
				if_tx_errors = { "aborted", "carrier", "fifo", "heartbeat", "window" },
				if_rx_errors = { "length", "missed", "over", "crc", "fifo", "frame" }
			},
			options = {	-- XXX: fixme (define colors...)
				if_tx_errors = {
					total = true
				},

				if_rx_errors = {
					flip  = true,
					total = true
				}
			}
		}
	}


	return { traffic, packets, multicast, collisions, errors }
end
